
import 'package:flutter/foundation.dart';
import 'package:xxstatistical/repository/datareport_repository.dart';
import 'package:xxstatistical/src/entity/datareport_entity.dart';
import 'package:xxstatistical/src/sql/Sqlite3Helper.dart';

class Statistical {
  Statistical._();

  static Statistical _instance;

  static Statistical create() {
    if (_instance == null) {
      _instance = Statistical._();
    }
    return _instance;
  }
  ///
  /// 设置缓存的最大数量(当达到最大数量之后就上传)
  ///
  int _cachesMax = 0;

  ///
  /// 计数，当前已经缓存的数据
  ///
  int _cachesNumber = 0;
  
  ///
  /// 初始化
  ///
  Future<Null> init({int cachesMax = 50}) async{
    this._cachesMax = cachesMax;
    int amount = await Sqlite3Helper.create().init();
    _cachesNumber = amount;
    if(_cachesNumber>=10){
      this._startUploadData();
    }
  }

  ///
  /// 记录数据
  /// [data]        待记录的数据
  ///
  void record({@required DataReportEntity data}) {
    _cachesNumber ++;
    print('上报数据=======> cachesNumber:$_cachesNumber');
    Sqlite3Helper.create().add(id:data.id,event:data.event,type:data.type,amount:data.amount);
    if(_cachesNumber >= _cachesMax){
      this._startUploadData();
    }
  }

  ///
  /// 开始上报数据
  ///
  Future<void> _startUploadData() async{
    List<Map<String, dynamic>> list = await Sqlite3Helper.create().query();
    DatareportRepository.create().dataReport(list: list).then((val){
      print('上报数据=======> $val');
      _cachesNumber = 0;
    }).whenComplete(() async{
      await Sqlite3Helper.create().deleteAll();
    });
  }
}